Package: synapsis
Type: Package
Title: An R package to automate the analysis of double-strand break
        repair during meiosis
Version: 1.18.0
Authors@R: 
    c(person(given = "Lucy",
             family = "McNeill",
             role = c("aut", "cre", "cph"),
             email = "luc.mcneill@gmail.com",
             comment = c(ORCID = "0000-0003-1752-4882")),
      person(given = "Wayne",
             family = "Crismani",
             role = c("rev", "ctb"),
             comment = c(ORCID = "0000-0003-0143-8293")))
Description: Synapsis is a Bioconductor software package for automated (unbiased and reproducible) analysis of meiotic immunofluorescence datasets. The primary functions of the software can i) identify cells in meiotic prophase that are labelled by a synaptonemal complex axis or central element protein, ii) isolate individual synaptonemal complexes and measure their physical length, iii) quantify foci and co-localise them with synaptonemal complexes, iv) measure interference between synaptonemal complex-associated foci. The software has applications that extend to multiple species and to the analysis of other proteins that label meiotic prophase chromosomes. The software converts meiotic immunofluorescence images into R data frames that are compatible with machine learning methods. Given a set of microscopy images of meiotic spread slides, synapsis crops images around individual single cells, counts colocalising foci on strands on a per cell basis, and measures the distance between foci on any given strand.
biocViews: Software, SingleCell
Depends: R (>= 4.1)
Imports: EBImage, stats, utils, graphics
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.1.1
VignetteBuilder: knitr
Suggests: knitr, rmarkdown, testthat (>= 3.0.0), ggplot2, tidyverse,
        BiocStyle
Config/testthat/edition: 3
git_url: https://git.bioconductor.org/packages/synapsis
git_branch: RELEASE_3_23
git_last_commit: e5748f3
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 23:42:21 UTC; biocbuild
Author: Lucy McNeill [aut, cre, cph] (ORCID:
    <https://orcid.org/0000-0003-1752-4882>),
  Wayne Crismani [rev, ctb] (ORCID:
    <https://orcid.org/0000-0003-0143-8293>)
Maintainer: Lucy McNeill <luc.mcneill@gmail.com>
Built: R 4.6.0; ; 2026-04-29 05:03:17 UTC; unix
